@@ -1,6 +1,6 @@
-from reportpl.widgets import TextWidget, ArrayWidget, TextAreaWidget, TypeAheadObjWidget, SelectWidget, CheckBoxWidget
+from reportpl.widgets import TextWidget
 from reportpl.types import ValidationError
-from reportpl.web_converters import DateConverter, FloatConverter
+from reportpl.web_converters import DateConverter
 from reportpl.base_web_form import BaseWebForm
 
 
@@ -11,6 +11,6 @@ class Form(BaseWebForm):
         self.widgets = [
             [
                 TextWidget(self, 'nome', default="", placeholder="Digite seu nome",required=True),
-                TextWidget(self, 'data_nascimento', label="Data de nascimento",converter=DateConverter()),
+                TextWidget(self, 'data_nascimento', label="Data de nascimento",converters=[DateConverter()]),
             ],
         ]
\ No newline at end of file
