@@ -26,7 +26,7 @@ class ObjectsPicsWidget:
                  label: str | None = None,
                  col: int = 0,
                  validators: list[ValidatorType] = [],
-                 converter: Optional[ConverterType] = None,
+                 converters: list[ConverterType] = [],
                  new_object_name: str = "Sem nome",
                  multiple=False) -> None:
         self.col = col
@@ -36,7 +36,7 @@ class ObjectsPicsWidget:
         self.label = label or stringcase.capitalcase(name)
         self.new_object_name = new_object_name
         self.validators = validators
-        self.converter = converter
+        self.converters = converters
 
     @staticmethod
     def get_data_from_folder(widget_folder: Path) -> Any:
@@ -76,8 +76,9 @@ class ObjectsPicsWidget:
             data[i]['pics'] = [{'path': str(
                 folder / pic['path']), 'selected': pic['selected']} for pic in obj['pics']]
         try:
-            self.data = self.converter(
-                self.form, data) if self.converter else data
+            self.data = data
+            for cv in self.converters:
+                self.data = cv(self.form, self.data)
         except ValidationError as e:
             return None, str(e)
         for v in self.validators:
