@@ -21,13 +21,13 @@ class PicsSubfolderWidget:
                  label: str | None = None,
                  col: int = 0,
                  validators: list[ValidatorType] = [],
-                 converter: Optional[ConverterType] = None) -> None:
+                 converters: list[ConverterType] = []) -> None:
         self.col = col
         self.form = form
         self.name = name
         self.label = label or stringcase.capitalcase(name)
         self.validators = validators
-        self.converter = converter
+        self.converters = converters
 
     def get_update_data(self, payload: Any) -> Any:
         pass
@@ -66,12 +66,17 @@ class PicsSubfolderWidget:
                         item['files'].append(str(entry2.absolute()))
                 data.append(item)
         self.data = data
-
+        try:
+            for cv in self.converters:
+                self.data = cv(self.form, self.data)
+        except ValidationError as e:
+            return None, str(e)
         for v in self.validators:
             try:
                 v(self.form, self.data)
             except ValidationError as e:
                 return None, str(e)
+
         return self.data, None
 
     def get_layout(self) -> WidgetAttributesType:
