@@ -10,7 +10,7 @@ from reportpl.types import ConverterType, ErrorsType, FileType, ValidatorType, W
 class Widget(Protocol):
 
     validators: list[ValidatorType]
-    converter: Optional[ConverterType]
+    converters: list[ConverterType]
     col: int
     name: str
     form: 'BaseWebForm'
